
%  get_Wocebottles.m;  an interface between the global
%  Woce bottle data set and Matlab. See Readme_getWocebottles.pdf for 
%    much more. 
%
%  By Jim Price, August 2006, with important help from Roger Goldsmith 
%   and Holly Dail. 
%  Revision of September 3, 2008.

format compact

j = 0;
disp('  ')
disp(' get_WOCEbottles.m;  an interface to the global WOCE bottle data set.')
disp('  ')
whocean = input(' Which ocean shall we sample, A, P or I?  (enter 1, 2 or 3)'  )
if whocean == 1
load Abottle;
D = Abottle;  
clear Abottle;
h1 = openfig('Atlanticmap.fig')
end

if whocean == 2
load Pbottle;
D = Pbottle;  
clear Pbottle; 
h1 = openfig('Pacificmap.fig')
end

if whocean == 3
load Ibottle;
D = Ibottle;  
clear Ibottle;
h1 = openfig('Indianmap.fig')
end

 whtitle = 'a subset of the WOCE Pacific ocean hydrographic data'

wsta =  unique((D.sect_id), 'rows')
j = 0;

hold on
longD = D.longitude;

if whocean == 1
    il = find(longD >= 100);
    longD(il) = longD(il) -360.;
end

if whocean == 2
    il = find(longD <= 0);
    longD(il) = longD(il) +360.;
end

hm = plot(longD, D.latitude, 'ro', 'Markersize', 2); 
 if whocean == 1
 axis([-80 20 -80 65 -10000 5000])
 whtitle = ' a subset of the WOCE Atlantic Ocean hydrographic data'
 xtt = -75.
 ytt = -10.
 end
 if whocean == 2
 axis([120 300 -75 65 -10000 5000])
 whtitle = 'a subset of the WOCE Pacific Ocean hydrographic data'
 xtt = 260.
 ytt = 40.
 end
 if whocean == 3
 axis([10 140 -75 30 -10000 5000])
 whtitle = 'a subset of the WOCE Indian Ocean hydrographic data'
 xtt = 18.
 ytt = 10.
 end
 
 title(whtitle)
 
 xlabel('east longitude')
 ylabel('north latitutde')
 
 hold on
 st(1) = {'mouse click to select'}
 st(2) = {'carriage return to end'}
 htt = text(xtt, ytt, st, 'fontsize', 10) 
 set(htt,'backgroundcolor', [1 1 1])
 pause(3.0)
 set(htt, 'visible', 'off')


 drawnow
 set(gcf, 'renderer', 'OpenGL')


% load coast
% hold on
% plot(long, lat, '-g')
% patch(long, lat, [0.5 0.5 0.5])

% axis([-90 20 -60 60])
% grid on
% drawnow

for k=1:50 
    
    if k == 1
        disp('  ')
        disp('  ')
        disp(' getWocebottles.m')
        disp('  ')
        disp(' Mouse click on the stations that you would like to collect. ')
        disp(' To end the data collection, hit a cartriage return ')
        disp('  while the pointer is within the figure window.')
        disp('  ')
        disp(' Before you exit Matlab, you may want to save the data')
        disp('  by entering the Matlab command -  save thisdata.mat A,') 
        disp('  where A is the structure that holds the collected data.')
    end
 
%  the following allows for input of station names, vs, the mouse
goj = 1;
    if goj == 0
secname = input('    enter the section name, A05 etc, or x to stop  ', 's')
if strmatch(secname, 'x') == 1
    return
end

clear ix1 ix
ix1 = strmatch(secname, D.sect_id);
stations = D.stnnbr(ix1);
sort(unique(stations));
stanum = input('   enter the station number  ' );
ix2 = find(D.stnnbr == stanum);
ix = intersect(ix1, ix2);
    end

%  select a station via mouse click
figure(h1)
[x, y] = ginput(1);
if isempty(x) == 1
disp('Reminder:  you may want to save the structure A before closing Matlab')
return
    
else    
latD = D.latitude;
r = ((longD - x).^2 + (latD -y).^2).^0.5;
ir = find(r == min(r));
ix = ir;

secname = D.sect_id(min(ir),:)
stanum = D.stnnbr(min(ir))


% BTL_show(D, ix, 2)

clear sta lat lon S T P O N Ph Si

sta = D.stnnbr(ix);
lat = D.latitude(min(ix));
lon = longD(min(ix));
S = D.salnty(ix);
T = D.ctdtmp(ix);
P = D.ctdprs(ix);
O = D.oxygen(ix);
N = D.nitrat(ix);
if strmatch(secname, 'A01W') == 1  
    N = D.no2_no3(ix);
end
if  strmatch(secname, 'A03') == 1
    N = D.no2_no3(ix);
end
Ph = D.phspht(ix);
Si = D.silcat(ix);
Name = [secname '  ' num2str(stanum)];

j = j+1;
A(j).name = Name;
A(j).lat = D.latitude(min(ix));
A(j).lon = longD(min(ix));
A(j).pre = P;
A(j).tem = T;
A(j).sal = S;
A(j).oxy = O;
A(j).nit = N;
A(j).pho = Ph;
A(j).sil = Si;

%  put a map marker on the seleced station 
figure(h1)
hold on
plot3(lon, lat, 0*lat,  'oy', 'markersize', 5)
text(lon, lat+3, num2str(j), 'color', [1 1 1])

%  make a plot of the selected station
figure(50+k)
clf reset

subplot(2,2,1)
hold on
plot(T, -P)
axis([-2 30 -6000 0])
xlabel('temperature, C')
ylabel('pressure, db')
title(['station ' num2str(k),',','   ', Name])
grid on

subplot(2,2,2)
hold on
plot(S, -P)
axis([34 37 -6000 0])
xlabel('salinity')
title([num2str(lat),'N','   ', num2str(lon),'E'])
grid on

subplot(2,2,3)
hold on
plot(O, -P)
axis([0 400 -6000 0])
xlabel('dis. oxygen, \mu M kg^{-1}')
ylabel('pressure, db')
grid on

subplot(2,2,4)
hold on
plot(Ph, -P)
axis([0 4 -6000 0])
xlabel('PO_4, \mu M kg^{-1}')
grid on

pause(1.0)
 
end   %  if on how stations are to be selceted

end    %  loop on k 




