

% Advection in a Stommel gyre, after hecht, wingate and kassis
%  
% Jim Price, Oct 2006

clear all
close all
format compact
warning('off')

set(0,'DefaultTextFontSize',14)
set(0,'DefaultAxesFontSize',14)
set(0,'DefaultAxesLineWidth',1.2)
set(0,'DefaultLineLineWidth',1.2)

%  define the gyre....
beta = 1.e-11;     %  df/dy,  1/(m sec)
r = 1.e-6;         %  frictional coefficient, 1/sec
alpha = (1/r)*beta;  

b = 6.3e6          %  basin north-south extent, m
lambda = 1.e7      %  basin width, m

A = -alpha/2 + (alpha^2/4 + (pi/b)^2)^0.5;
B = -alpha/2 - (alpha^2/4 + (pi/b)^2)^0.5;

p = (1 - exp(B*lambda))/(exp(A*lambda) - exp(B*lambda)); 
q = 1 - p;

F = 0.1;           %  wind dtress amplitude, Pa
gamma = F*pi/(r*b);

D = 200            %  layer thickness, m
rho = 1025.;

dx = 0.5e5;
x = 0:dx:lambda;
y = 0:dx:b;

nx = length(x);
ny = length(y);

for j=1:nx   
    for k=1:ny      
       psi(k,j) = (1/rho)*gamma*((b/pi)^2)*sin(pi*y(k)/b)*....
            (p*exp(A*x(j)) + q*exp(B*x(j)) - 1.0);
       u(k,j) = usg(x(j), y(k), rho, D, p, A, q, B, b, gamma);
       v(k,j) = vsg(x(j), y(k), rho, D, p, A, q, B, b, gamma);     
    end
end

    figure(1)
    clf reset    
    mesh(x/1000, y/1000, -psi/1.e6)
    xlabel('x')
    ylabel('y')
    
    figure(2)
    clf reset
    [c h] = contour(x/1000, y/1000, -psi/1.e6, [0.001, 4:8:60]);
    clabel(c, h)
    xlabel('x')
    ylabel('y')
    axis([0 10000 0 6300])
    title('Stommel gyre streamlines, Sv')
    
    figure(6)
    clf reset
    contour(x/1000, y/1000, -psi/1.e6, [0.001, 4:8:60], 'b');
    xlabel('x')
    ylabel('y')
    axis([0 10000 0 6300])
    title('advection in a Stommel gyre')
notthis = 1
if notthis == 0
    figure(3)
    clf reset 
    [c h] = contour(x/1000, y/1000, u, [0.001, -1:0.05:1]);
    clabel(c, h)
    xlabel('x')
    ylabel('y')
    axis([0 10000 0 6300])
    title('Stommel gyre')  
    
    figure(4)
    clf reset    
    [c h] = contour(x/1000, y/1000, v, [-2 -1 -0.01 0 0.01 1 2]);
    clabel(c, h)
    xlabel('x')
    ylabel('y')
    axis([0 10000 0 6300])
    title('Stommel gyre')
end   
    
    figure(5)
    clf reset
    quiver(x/1000, y/1000, u, v)
    xlabel('x')
    ylabel('y')
    axis([0 10000 0 6300])
    title('Stommel gyre')
    
    nstep = 65000
    dt = 0.2e4;
    xf = zeros(nstep,1);
    yf = xf;
    
    x0 = 1000.e3;
    y0 = 2000.e3;
    nth = 1
    rad = 750.e3
    for n=1:nth
    thta = 0 + (n-1)*2*pi/(nth-1);
    xf(1) = x0 + rad*cos(thta);
    yf(1) = y0 + rad*sin(thta);
    x1(n) = xf(1);
    y1(n) = yf(1);
   
    for m = 2:nstep 
        uf = usg(xf(m-1), yf(m-1), rho, D, p, A, q, B, b, gamma);
        vf = vsg(xf(m-1), yf(m-1), rho, D, p, A, q, B, b, gamma);      
        xf(m) = xf(m-1) + dt*uf;
        yf(m) = yf(m-1) + dt*vf;
    end
    xn(n) = xf(m);
    yn(n) = yf(m);
    
    figure(5)
    hold on
    plot(xf/1000, yf/1000, 'r')
    
    figure(2)
    hold on
    plot(xf/1000, yf/1000, 'r')
   
    end    %   loop on n 

%
%  advect a blob of tracer around the gyre
%
    clear xf yf 
    
    dt = 2000.;              %  time step, sec
    nett = 2e8;              %  total time, sec
    nstep = floor(nett/dt)
        
    x0 = lambda/3;          %  initial center point
    y0 = b/3;    
    
    nth = 100;              %  use this many points to define perimeter
    nthh = nth/2
    
%  compute starting positions;  assume a circle of radius rad
    rad = 750e3;
    for n=1:nth
    thta = 0 + (n-1)*2*pi/(nth-1);
    xf(n) = x0 + rad*cos(thta);
    yf(n) = y0 + rad*sin(thta);
    end     

    chunks = 6             %  advect in this many steps
    nsc = floor(nstep/chunks);
    
    for m = 1:chunks;
        
        figure(6)
        hold on
        patch(xf/1000, yf/1000, [0 1 0]);
        plot(xf(1:nthh)/1000, yf(1:nthh)/1000, 'r', 'linewidth', 1.7);
        plot(xf(nthh+1:nth)/1000, yf(nthh+1:nth)/1000, 'b', 'linewidth', 1.7);
        drawnow      
        [area aa bb] = polygeom(xf, yf);
        Arean(m) = area(1,1)/1.e6;
        Perimn(m) = area(1,4)/1.e3;
        time(m) = m*nsc*dt/(365*8.64e4);
%
%  time step the blob position using a second order RK method
%
        for n = 1:nsc;      %  inner time step loop
        ufh = usg(xf, yf, rho, D, p, A, q, B, b, gamma);   % velocity
        vfh = vsg(xf, yf, rho, D, p, A, q, B, b, gamma);            
        xh = xf + dt*ufh/2;                                % take a half step
        yh = yf + dt*vfh/2;
        uf = usg(xh, yh, rho, D, p, A, q, B, b, gamma);    % velocity at mid point
        vf = vsg(xh, yh, rho, D, p, A, q, B, b, gamma);      
        xf = xf + dt*(uf + ufh)/2;                         % take a full step
        yf = yf + dt*(vf + vfh)/2;    
        end
                             
    end   %  loop on chunks
  
    
   figure(7)
   clf reset
    
   subplot(2,1,1)
   plot(time, Arean)
   ylabel('Area')
   xlabel('time, years')
   
   subplot(2,1,2)
   plot(time, Perimn)
   ylabel('perimeter')
   xlabel('time, years')
   
   

