
%  mix_1d;  elementary mixing in one-dimension.  Variables are dimensional
%  and assigned values that are consistent with the N Atlantic Tracer
%  Release Experiment, see Ledwell et al., JGR-Oceans,
%  103(c10), Sep. 1998, 21499-21529.  
%
%  script by Jim Price, Oct 2005; modified in Oct 2006, Aug 2007.
%
%  public domain for all personal, educational purposes
%

clear all, close all

set(0,'DefaultAxesFontSize',13)
set(0,'DefaultTextFontSize',13)
set(0,'DefaultAxesLineWidth', 1.3)
set(0,'DefaultLineLineWidth', 1.0)
format compact

%  define the grid, SI coordinates
dz = 2.0;         %  the grid interval
L = 300.;         %  the total length
z = -L:dz:0;      %  the spatial coordinate
nz = length(z);


days = input(' enter the no. of days to integrate, (100  to  900  to  2000)   ')

% set the time step and the number of steps to take
dt = 7200.;                             %  the time step in seconds
nstep = floor(days*8.64e4/dt) + 10;     %  do this many steps 

%  set the initial condition for the scalar tracer variable a
a = zeros(1,nz);
for j=1:nz
    if (abs((z(j)+L/2))) <= 10.   %  a square patch of 10 m half-thickness
        a(j) = 1.0;
    end
end
initiala = a;
ICa = sum(a)*dz;

%  arrays of indices needed to estimate derivatives
ip = [1 3:nz nz];
im = [1 1:nz-2 nz];

%  define the diffusion coefficient
K = input('  enter K [m*2/sec], (0.1e-6  to  0.1e-4  to  0.1e-2)  ')


% you might choose K such that this numerical solution will not converge - check this
disp(' for a stable numerical solution,  the non-dimensional K should')
disp('   be less than 1/4;  Knd for this K and dt, dz is: ')
Knd = K/(dz^2/dt)       %  the nondimensional diffusion 

U = 0.;       %  set advection = 0 for now

figure(1); clf reset  % send the plots here

% enough of this chit chat,  let's start diffusing
for n = 1:nstep

%  first a little diffusion,  estimate the Laplacian
d2a = ((a(ip) + a(im)) - 2*a)/dz^2;

%  estimate the first derivative by a centered difference;
%    needed for advection (not used here)
da = (a(ip) - a(im))/(2*dz);

%  now define the BCs: setting zero on the ends of d2a amounts
%  to leaving the end points fixed in time at their initial values 
d2a(1) = 0.;
d2a(nz) = 0.; 

%  take a time step
 a = a + dt*(K*d2a - U*da);

%  make a plot, occasionally
plotint = 1200;     %  plot the a array every this many time steps
if mod(n,plotint) == 1

%  evaluate and plot the Green's function solution
%  this assumes a Gaussian (not a square pulse) IC and so
%  will not look the numerical solution for short times

t = n*dt;             %  the time
for j=1:nz
zp = z(j) + L/2;      %  z distance from the center of the tracer IC
G(j) = ICa*(1/(2*sqrt(pi*K*t)))*exp(-zp^2/(4*t*K));
end
if exist('hG', 'var'); set(hG, 'visible', 'off'); end
hG = plot(G, z, 'g', 'linewidth', 1.5);

%  now plot the numerical solution.....
hold on
if exist('ha', 'var'); set(ha, 'visible', 'off'); end
ha = plot(a, z,'r.', 'linewidth', 0.6);
axis([0. 0.2 -L 0])
legend('Green`s function',  'numerical', 'IC')
legend boxoff
day = n*dt/8.64e4;
if exist('hd', 'var'); set(hd, 'visible', 'off'); end
hd = text(0.1, -L/5, ['day =  ' num2str(day,4)]);
xlabel('tracer, a'); ylabel('depth, z, m');  grid on; 

axis([0. 1.2 -L 0])
title(['mix\_1d; elementary diffusion in 1-d, K = ', num2str(K), ' m^2 sec^{-1}'])
plot(initiala, z)   %  plot the initial a profile
drawnow
disp( ' ')
disp('  hit any key to continue the integration   ')
pause   %  pause for just a bit so that you can see the result

%  at this line in the script, you have the a and the z vectors and so
%  can do whatever kind of disagnostic you might want 
%  at each plotting time step - if you want every time step, then
%  look just below the next end. 

end   %  if on plot or not 

end   %  time step loop on n 

%  done

