
%  random mixing
%  show that random mixing can act a lot like diffusion
%  
%  by Jim Price, Oct, 2005
%  public domain for all personal educational purposes

clear all
close all

set(0,'DefaultAxesFontSize',13)
set(0,'DefaultTextFontSize',13)
set(0,'DefaultAxesLineWidth', 1.3)
set(0,'DefaultLineLineWidth', 1.0)
format compact

figure(1)
clf reset

ns = 0;  ns2 = 0;
%  first, the random mixing method
%  set up the grid
L = 100.
dz = 1;
z = -L:dz:0;
nz = length(z);

%  set the initial tracer distribution
a = 0*z;
for j=1:nz
    if abs(z(j)) >= 40 & abs(z(j)) <= 60
        a(j) = a(j) + 0.2;
    end
end

%  pad the ends of the a array
a = [a(1) a a(nz)];
z = [z(1) z z(nz)];

%  do nm mixing events, distributed randomly throughout the a profile
nm = 50000;            %  50000 is about right
r = rand(nm,1);

%  plot the IC
subplot(1,2,1)
plot(a, z, 'g', 'linewidth', 2)
pause(2.)

%  now execute the random (local) mixing events
for j=1:nm
    
i = round(r(j,1)*99) + 2;   %  select the level to mix

%  the first scheme, which is most easily identified with the 
%     diffusion eqn.
% da = 0.25*(a(i+1) + a(i-1) - 2*a(i));
% a(i) = a(i) + da; 
%  note that a conservation is not imposed here locally, as only the 
%  central level is changed, i.e., a is not conserved at each step

%  a second scheme that imposes a conservation at each step
f = 0.25/2;        %  seems sensible since about 2x as much mixing occurs       
dap = a(i) - a(i+1);
dam = a(i) - a(i-1);
a(i) = a(i) - f*(dap + dam);
a(i+1) = a(i+1) + f*dap;
a(i-1) = a(i-1) + f*dam;


if (mod(j,5000)) == 1       %  plot occasionally
  hold on
  plot(a, z)
  drawnow
  ns = ns + 1;
  asum(ns) = sum(a);
  timesum(ns) = j;
end
end
plot(a, z, 'r')     % add the last step in red
grid on
text(0.02, -5., 'random mixing')
text(0.02, -11., '500 times each level')
xlabel(' tracer, a')
ylabel('depth, z')
plot(a, z, 'r', 'linewidth', 2)
axis([-0.05 0.25 -100 0])
%  all done with random mixing

%  now integrate the diffusion eqn:
subplot(1,2,2)
clear a z

%  use the same grid and IC
z = -L:dz:0;
nz = length(z);
a = 0*z;
for j=1:nz
    if abs(z(j)) >= 40 & abs(z(j)) <= 60
        a(j) = a(j) + 0.2;
    end
end

subplot(1,2,2)
plot(a, z, 'g', 'linewidth', 2)
pause(2.)
text(0.02, -5., 'diffusion eqn, K = 0.25,')
text(0.02, -11., '500 times steps')

%  arrays of indices useful in estimating the laplacian
ip = [1 3:nz nz];
im = [1 1:nz-2 nz];

%  set K to match the random mixing done above
dt = 1.;
K = 0.25;
for j=1:round(nm/nz)    % do nm/nz steps

d2a = ((a(ip) + a(im)) - 2*a)/dz^2;
a = a + dt*K*d2a;

if (mod(j,50)) == 1   %  plot occasionally
   hold on
   plot(a, z)
   drawnow
   ns2 = ns2 + 1;
   timeint(ns2) = j*100;
   asumint(ns2) = sum(a);
end

end    %  time stepping loop on j
plot(a, z, 'r', 'linewidth', 2)
grid on
xlabel(' tracer, a')
axis([-0.05 0.25 -100 0])

figure(2)
plot(timesum, asum, timeint, asumint, 'r')
xlabel('time')
ylabel('a sum')

