
%  randomwalk_2d; compute a random walk in 2-d
%
%  this is an elementary model of a random walk that is useful for
%  showing the dependence of dispersion upon speed and time scale, 
%  the time bewteen random course changes which is proportional to 
%  the integral time scale. also useful for seeing the effect of
%  a spatially varying K (via U), and for seeing the statistical
%  variability of, say, dispersion.  how many floats do you need
%  to get a stable estimate?  (quite a few!)
%
%  by Jim Price, Oct 2005.
%
%  public domain for all personal, educational purposes.

set(0,'DefaultAxesFontSize',13)
set(0,'DefaultTextFontSize',13)
set(0,'DefaultAxesLineWidth', 1.3)
set(0,'DefaultLineLineWidth', 1.0)
format compact

clear all
close all

np = 30;     %  define the number of floats 
npi = input( ' enter the number of floats (nominal = 30)  ');
if isempty(npi) == 0; np = npi;  end


itimedays = 8;    %  time between random course changes, days (about 8 for NATRE)
itimedaysi = input...
     (' enter the time between random course changes, days (nominal = 8) ');
if isempty(itimedaysi) == 0; itimedays = itimedaysi;  end
itime = itimedays*8.64e4;

U0 = 0.1;     % the float (pirate)  speed in m/sec;  for NATRE, about 0.1
U0i = input(' enter the speed, m/sec (nominal = 0.10) ');
if isempty(U0i) == 0; U0 = U0i;  end

% if you want a spatially dependent U, and thus K, set it here
% dUdy = 0.1/1000.      %  units are (m/sec)/km
dUdy = 0.;

%  define how long to run the inegration
ndays = 900;
ndaysi = input(' enter the number of days to integrate (nominal = 900) ');
if isempty(ndaysi) == 0;  ndays = ndaysi;  end
nsteps =  round(ndays/itimedays);

x = zeros(nsteps, np);
y = x;
day = zeros(1,nsteps);

rand('state',sum(100*clock))
r = 2*pi*rand(nsteps, np);

U = ones(1, np);

for j=2:nsteps
    day(j) = j*itimedays;
    U = U0 + y(j-1,:)*dUdy;    %  for a y-dependent U
    x(j,:) = x(j-1,:) + itime*U.*cos(r(j,:))/1000.;   %  x and y in km
    y(j,:) = y(j-1,:) + itime*U.*sin(r(j,:))/1000.;    
end

%  now for some diagnostics:
xrms = std(x');    %  the ( )' is to get the rows and columns the right way
yrms = std(y');

xm = mean(x');
ym = mean(y');

xmed = median(x');
ymed = median(y');

%  an estimate of the dispersion
rmsdispers = sqrt(day*8.64e4*itimedays*8.64e4*(U0/sqrt(2))^2)/1000.;

figure(1), clf reset
plot(x, y)
xlabel('east displacement, km')
ylabel('north displacement, km')
grid on
title([num2str(np), ' pirates on shore leave'])
axis('equal')


figure(2),  clf reset
plot(day, xrms, day, yrms, 'r')
hold on
plot(day, rmsdispers, 'g')
xlabel('time, days')
ylabel(' rms displacement, km')
grid on
title('rms displacements')


%  mean and median displacements
figure(3), clf reset
subplot(2,1,1)
plot(day, xm, day, ym, 'r')
grid on
ylabel(' mean x,y, km')

subplot(2,1,2)
plot(day, xmed, day, ymed, 'r')
grid on
xlabel('time, days')
ylabel(' median x,y, km')

%  histograms
figure(4), clf reset;
subplot(2,2,1)
hist(x(nsteps, :), 20)
xlabel('east-west distance, km')
ylabel('pirate density')

subplot(2,2,2)
hist(y(nsteps, :), 20)
xlabel('north-south distance, km')
ylabel('pirate density')

figure(3)
figure(2)
figure(1)

