
function strht = strht(s,t,z,zref);

% Computes steric height from hydrographic station data.
% s is salinity, t is temperature insitu [C], z is the depth [m],
% or the pressure [db] (these should be vectors of the same dimension). 
% zref is the single depth (or pressure) that will be used as the 
% reference level.  

% To make dynamic height (or geopotential anomaly) from this steric height, 
% just multiply by g.

% Written by Jim Price.  revised in July, 2005.  

path(path,'..\seawater')

r0 = 1028.;                        % A nominal sea water density.
zabs = abs(z);                     % To make sure that z increases downwards.
delta = sw_svan(s,t,zabs);         % Compute the specific volume anomaly, delta.

% Now, compute the steric height by summing from the bottom up.

m = length(delta);                     % Find the array size.
strhts = 0.;                           % Initialize a dummy variable.
strht(m) = 0.;                         % Set the deepest steric height to zero.                             
                        
for i = m-1: -1: 1;                    % Sum from the bottom up.
  dz = zabs(i+1) - zabs(i);            % Depth interval for these two points.
  delav = (delta(i+1) + delta(i))/2.;  % Mid-point specifc volume anomaly.  
  strhts = strhts + r0*dz*delav;       % Sum the steric height.  
  strht(i) = strhts;                   % Store the sum in the output array.
end

% Subtract the steric height at the reference level, zref. 

shref = spline(zabs,strht,abs(zref));  % Find the streric height at zref.
strht = strht - shref;                 % Apply this as a reference level.

% You're all done!















