

% Compute steric height from hydrographic station data.
% The input required is:
% s is salinity, t is temperature insitu [C], z is the depth [m],
% or the pressure [db]. These should be vectors of the same dimension. 
% zref is a single depth (or pressure) that will be used as the 
% reference level.  

function strht = strht_jp(s, t, z, zref);

% To make dynamic height (or geopotential anomaly) from this steric height, 
% just multiply by g.

% Written by Jim Price; revised in November, 2005.  

path(path,'.\seawater')            % needs the seawater library

r0 = 1028.;                        % a nominal sea water density
zabs = abs(z);                     % to make sure that z increases downwards
nz = length(z);
S35 = 35.*ones(1,nz);
T0 = 0*S35;

%  Compute a density anomaly following the usual convention for 
%     specific volume anomaly.

delrho = sw_dens(s, t, zabs) - sw_dens(S35, T0, zabs);

% Compute the steric height by summing from the bottom up.

strhts = 0.;                               % initialize a dummy variable
strht(nz) = 0.;                            % set the deepest steric height to zero 

for i = nz-1: -1: 1;                       % sum from the bottom up
  dh = abs(zabs(i+1) - zabs(i));           % thickness interval for these two points
  delrhoav = (delrho(i+1) + delrho(i))/2.; % the average density anomaly
  strhts = strhts - dh*delrhoav/r0;        % do the integral,  note the sign
  strht(i) = strhts;                       % store the sum in the output array
end

% Subtract the steric height at the reference level, zref. 

shref = spline(zabs, strht, abs(zref));   % find the streric height at zref
strht = strht - shref;                    % apply this as a reference level

% You're all done!  Now that wasn't too bad, was it?




